clyther — Clyther 0.2.0-beta documentation

### Navigation

- index
- modules |
- Clyther 0.2.0-beta documentation »
- Module code »

# Source code for clyther

    '''
    clyther
    ---------------------------

    '''

    from __future__ import print_function

    from cly_kernel import kernel, global_work_size, local_work_size, developer, task, cache

    from clyther.queue_record import QueueRecord

### Navigation

- index
- modules |
- Clyther 0.2.0-beta documentation »
- Module code »